@@ -17,7 +17,10 @@ def add_pct_skills(skill_library):
     auto_timing = get_auto_timing()
 
     pct_caster_tax_ms = 100
-    instant_timing_spec = TimingSpec(base_cast_time=0, animation_lock=pct_caster_tax_ms)
+    base_animation_lock = 600
+    instant_timing_spec = TimingSpec(
+        base_cast_time=0, animation_lock=base_animation_lock + pct_caster_tax_ms
+    )
     skill_library.set_current_job_class("PCT")
 
     rainbow_bright_follow_up = FollowUp(
@@ -86,10 +89,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Fire in Red",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=400),
+            damage_spec=DamageSpec(potency=440),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -103,10 +106,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Aero in Green",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=440),
+            damage_spec=DamageSpec(potency=480),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -120,10 +123,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Water in Blue",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=480),
+            damage_spec=DamageSpec(potency=520),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -138,10 +141,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Fire II in Red",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=80),
+            damage_spec=DamageSpec(potency=120),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -155,10 +158,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Mog of the Ages",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=1100),
+            damage_spec=DamageSpec(potency=1300),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -167,10 +170,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Pom Muse",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=1000),
+            damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -179,10 +182,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Winged Muse",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=1000),
+            damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -191,10 +194,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Aero II in Green",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=100),
+            damage_spec=DamageSpec(potency=140),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -208,10 +211,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Water II in Blue",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=120),
+            damage_spec=DamageSpec(potency=160),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -226,13 +229,13 @@ def add_pct_skills(skill_library):
             name="Hammer Stamp",
             is_GCD=True,
             damage_spec=DamageSpec(
-                potency=520,
+                potency=560,
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                 guaranteed_dh=ForcedCritOrDH.FORCE_YES,
             ),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -241,10 +244,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Blizzard in Cyan",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=700),
+            damage_spec=DamageSpec(potency=800),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -259,10 +262,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Blizzard II in Cyan",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=160),
+            damage_spec=DamageSpec(potency=240),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -277,10 +280,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Stone in Yellow",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=740),
+            damage_spec=DamageSpec(potency=840),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -295,10 +298,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Thunder in Magenta",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=780),
+            damage_spec=DamageSpec(potency=880),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -313,10 +316,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Stone II in Yellow",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=180),
+            damage_spec=DamageSpec(potency=260),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -331,10 +334,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Thunder II in Magenta",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=200),
+            damage_spec=DamageSpec(potency=280),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -344,31 +347,41 @@ def add_pct_skills(skill_library):
                 "1 Hyperphantasia": (rainbow_bright_follow_up,),
             },
         )
-    )
+    )    
 
     skill_library.add_skill(
         Skill(
             name="Starry Muse",
             is_GCD=False,
-            timing_spec=TimingSpec(
-                base_cast_time=0,
-                animation_lock=pct_caster_tax_ms
-            ),
-            buff_spec=StatusEffectSpec(
-                damage_mult=1.05, duration=20 * 1000, is_party_effect=True
-            ),
-            job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=5),),
-            follow_up_skills=(inspiration_follow_up,),
+            timing_spec=TimingSpec(base_cast_time=0, animation_lock=base_animation_lock + pct_caster_tax_ms),
+            buff_spec={
+                SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
+                    damage_mult=1.05, duration=int(20.35 * 1000), is_party_effect=True
+                ),
+                "Longest": StatusEffectSpec(
+                    damage_mult=1.05, duration=int(21.5 * 1000), is_party_effect=True
+                ),
+            },
+            job_resource_spec={
+                SimConsts.DEFAULT_CONDITION: (
+                    JobResourceSpec(name="Hyperphantasia", change=5),
+                ),
+                "Buff Only": tuple(),
+            },
+            follow_up_skills={
+                SimConsts.DEFAULT_CONDITION: (inspiration_follow_up,),
+                "Buff Only": tuple(),
+            },
         )
     )
     skill_library.add_skill(
         Skill(
             name="Holy in White",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=480),
+            damage_spec=DamageSpec(potency=520),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -383,13 +396,13 @@ def add_pct_skills(skill_library):
             name="Hammer Brush",
             is_GCD=True,
             damage_spec=DamageSpec(
-                potency=580,
+                potency=620,
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                 guaranteed_dh=ForcedCritOrDH.FORCE_YES,
             ),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -399,13 +412,13 @@ def add_pct_skills(skill_library):
             name="Polishing Hammer",
             is_GCD=True,
             damage_spec=DamageSpec(
-                potency=640,
+                potency=680,
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                 guaranteed_dh=ForcedCritOrDH.FORCE_YES,
             ),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -414,10 +427,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Comet in Black",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=780),
+            damage_spec=DamageSpec(potency=880),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -432,17 +445,17 @@ def add_pct_skills(skill_library):
         Skill(
             name="Rainbow Drip",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=900),
+            damage_spec=DamageSpec(potency=1000),
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=4000,
-                    animation_lock=pct_caster_tax_ms,
+                    animation_lock=base_animation_lock + pct_caster_tax_ms,
                     application_delay=650,
                     gcd_base_recast_time=6000,
                 ),
                 "Rainbow Bright": TimingSpec(
                     base_cast_time=0,
-                    animation_lock=pct_caster_tax_ms,
+                    animation_lock=base_animation_lock + pct_caster_tax_ms,
                     application_delay=650,
                     gcd_base_recast_time=int(0.4 * 6000),  # 60% reduction?
                 ),
@@ -453,10 +466,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Clawed Muse",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=1000),
+            damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -465,10 +478,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Fanged Muse",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=1000),
+            damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -477,10 +490,10 @@ def add_pct_skills(skill_library):
         Skill(
             name="Retribution of the Madeen",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=1300),
+            damage_spec=DamageSpec(potency=1400),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -489,11 +502,11 @@ def add_pct_skills(skill_library):
         Skill(
             name="Star Prism",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=1300),
+            damage_spec=DamageSpec(potency=1400),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
-                application_delay=650,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                application_delay=1250,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
             follow_up_skills={
@@ -550,7 +563,7 @@ def add_pct_skills(skill_library):
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -561,7 +574,7 @@ def add_pct_skills(skill_library):
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -572,7 +585,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
@@ -585,7 +598,7 @@ def add_pct_skills(skill_library):
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -597,7 +610,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
@@ -610,7 +623,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
@@ -623,7 +636,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
@@ -635,7 +648,7 @@ def add_pct_skills(skill_library):
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -646,7 +659,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
@@ -658,7 +671,7 @@ def add_pct_skills(skill_library):
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -669,7 +682,7 @@ def add_pct_skills(skill_library):
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -681,7 +694,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
@@ -693,7 +706,7 @@ def add_pct_skills(skill_library):
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -704,7 +717,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
@@ -716,7 +729,7 @@ def add_pct_skills(skill_library):
             is_GCD=False,
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 application_delay=650,
             ),
         )
@@ -727,7 +740,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
@@ -739,7 +752,7 @@ def add_pct_skills(skill_library):
             is_GCD=True,
             timing_spec=TimingSpec(
                 base_cast_time=3000,
-                animation_lock=pct_caster_tax_ms,
+                animation_lock=base_animation_lock + pct_caster_tax_ms,
                 gcd_base_recast_time=4000,
                 application_delay=650,
             ),
