@@ -54,6 +54,7 @@ def add_smn_skills(skill_library):
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=440,
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -62,6 +63,7 @@ def add_smn_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=100),
             timing_spec=instant_timing_spec,
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -101,30 +103,35 @@ def add_smn_skills(skill_library):
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=540,
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
         Skill(
             name="Deathflare",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=500),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=500)},
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=800,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
         Skill(
             name="Ruin IV",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=490),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=490)},
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=800,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
         )
     )
     skill_library.add_skill(
@@ -142,16 +149,19 @@ def add_smn_skills(skill_library):
         skill=Skill(
             name="Akh Morn (pet)",
             is_GCD=False,
-            damage_spec=DamageSpec(
+            damage_spec= {SimConsts.DEFAULT_CONDITION: DamageSpec(
                 potency=1300,
                 damage_class=DamageClass.PET,
                 pet_job_mod_override=100,
                 pet_scalar=0.88,
-            ),
+            )},
+            has_aoe=True,
+            aoe_dropoff=0.6
         ),
         delay_after_parent_application=0,
         snapshot_buffs_with_parent=False,
         snapshot_debuffs_with_parent=False,
+        primary_target_only=False
     )
 
     skill_library.add_skill(
@@ -174,7 +184,7 @@ def add_smn_skills(skill_library):
         Skill(
             name="Ruby Rite",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=580),
+            damage_spec=DamageSpec(potency=540),
             timing_spec=TimingSpec(
                 base_cast_time=2800,
                 gcd_base_recast_time=3000,
@@ -187,7 +197,7 @@ def add_smn_skills(skill_library):
         Skill(
             name="Topaz Rite",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=380),
+            damage_spec=DamageSpec(potency=340),
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 gcd_base_recast_time=2500,
@@ -200,7 +210,7 @@ def add_smn_skills(skill_library):
         Skill(
             name="Emerald Rite",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=270),
+            damage_spec=DamageSpec(potency=240),
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 gcd_base_recast_time=1500,
@@ -218,13 +228,14 @@ def add_smn_skills(skill_library):
                 base_cast_time=1500,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
         Skill(
             name="Fountain of Fire",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=620),
+            damage_spec=DamageSpec(potency=580),
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
@@ -242,23 +253,27 @@ def add_smn_skills(skill_library):
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=800,
             ),
+            has_aoe=True,
         )
     )
     revelation_follow_up = FollowUp(
         Skill(
             name="Revelation (pet)",
             is_GCD=False,
-            damage_spec=DamageSpec(
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(
                 potency=1300,
                 damage_class=DamageClass.PET,
                 pet_job_mod_override=100,
                 pet_scalar=0.88,
-            ),
+            )},
             timing_spec=instant_timing_spec,
+            has_aoe=True,
+            aoe_dropoff=0.6
         ),
         delay_after_parent_application=0,
         snapshot_buffs_with_parent=0,
         snapshot_debuffs_with_parent=0,
+        primary_target_only=False
     )
     skill_library.add_skill(
         Skill(
@@ -287,6 +302,7 @@ def add_smn_skills(skill_library):
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=535,
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -300,6 +316,7 @@ def add_smn_skills(skill_library):
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=535,
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
@@ -313,42 +330,49 @@ def add_smn_skills(skill_library):
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=535,
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
         Skill(
             name="Crimson Cyclone",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=490),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=490)},
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=800,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.65
         )
     )
     skill_library.add_skill(
         Skill(
             name="Crimson Strike",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=490),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=490)},
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=760,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.65
         )
     )
     skill_library.add_skill(
         Skill(
             name="Mountain Buster",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=170),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=160)},
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=760,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.7
         )
     )
 
@@ -356,6 +380,7 @@ def add_smn_skills(skill_library):
         name="Slipstream (dot)",
         is_GCD=False,
         damage_spec=DamageSpec(potency=30, damage_class=DamageClass.MAGICAL_DOT),
+        has_aoe=True
     )
     slipstream_follow_up = FollowUp(
         skill=slipstream_dot,
@@ -363,12 +388,13 @@ def add_smn_skills(skill_library):
         dot_duration=15 * 1000,
         snapshot_buffs_with_parent=True,
         snapshot_debuffs_with_parent=False,
+        primary_target_only=False
     )
     skill_library.add_skill(
         Skill(
             name="Slipstream",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=490),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=490)},
             timing_spec=TimingSpec(
                 base_cast_time=3000,
                 gcd_base_recast_time=3500,
@@ -376,17 +402,21 @@ def add_smn_skills(skill_library):
                 application_delay=1020,
             ),
             follow_up_skills=(slipstream_follow_up,),
+            has_aoe=True,
+            aoe_dropoff=0.65
         )
     )
     inferno = Skill(
         name="Inferno (pet)",
         is_GCD=True,
-        damage_spec=DamageSpec(
-            potency=860,
+        damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(
+            potency=800,
             damage_class=DamageClass.PET,
             pet_job_mod_override=100,
             pet_scalar=0.88,
-        ),
+        )},
+        has_aoe=True,
+        aoe_dropoff=0.6
     )
     # Model the 2.1s snap with this hack. Damage will not come out correctly though.
     inferno_follow_up = FollowUp(
@@ -394,6 +424,7 @@ def add_smn_skills(skill_library):
         snapshot_buffs_with_parent=False,
         snapshot_debuffs_with_parent=False,
         delay_after_parent_application=2100,
+        primary_target_only=False
     )
     skill_library.add_skill(
         Skill(
@@ -406,12 +437,14 @@ def add_smn_skills(skill_library):
     earthen_fury_blast = Skill(
         name="Earthen Fury (pet)",
         is_GCD=True,
-        damage_spec=DamageSpec(
-            potency=860,
+        damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(
+            potency=800,
             damage_class=DamageClass.PET,
             pet_job_mod_override=100,
             pet_scalar=0.88,
-        ),
+        )},
+        has_aoe=True,
+        aoe_dropoff=0.6
     )
     # Model the 2.1s snap with this hack. Damage will not come out correctly though.
     earthen_fury_follow_up = FollowUp(
@@ -419,6 +452,7 @@ def add_smn_skills(skill_library):
         snapshot_buffs_with_parent=False,
         snapshot_debuffs_with_parent=False,
         delay_after_parent_application=2100,
+        primary_target_only=False
     )
     skill_library.add_skill(
         Skill(
@@ -431,12 +465,14 @@ def add_smn_skills(skill_library):
     aerial_blast = Skill(
         name="Aerial Blast (pet)",
         is_GCD=True,
-        damage_spec=DamageSpec(
-            potency=860,
+        damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(
+            potency=800,
             damage_class=DamageClass.PET,
             pet_job_mod_override=100,
             pet_scalar=0.88,
-        ),
+        )},
+        has_aoe=True,
+        aoe_dropoff=0.6
     )
     # Model the 2.1s snap with this hack. Damage will not come out correctly though.
     aerial_blast_follow_up = FollowUp(
@@ -444,6 +480,7 @@ def add_smn_skills(skill_library):
         snapshot_buffs_with_parent=False,
         snapshot_debuffs_with_parent=False,
         delay_after_parent_application=2100,
+        primary_target_only=False
     )
     skill_library.add_skill(
         Skill(
@@ -457,7 +494,7 @@ def add_smn_skills(skill_library):
         Skill(
             name="Necrotize",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=440),
+            damage_spec=DamageSpec(potency=420),
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
@@ -475,6 +512,7 @@ def add_smn_skills(skill_library):
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=930,
             ),
+            has_aoe=True
         )
     )
 
@@ -517,7 +555,7 @@ def add_smn_skills(skill_library):
                     skill=scarlet_flame_skill_for_follow_up,
                     delay_after_parent_application=0,
                     snapshot_buffs_with_parent=False,
-                    snapshot_debuffs_with_parent=False,
+                    snapshot_debuffs_with_parent=False,                    
                 ),
             ),
         )
@@ -627,7 +665,7 @@ def add_smn_skills(skill_library):
             name="Luxwave",
             is_GCD=False,
             damage_spec=DamageSpec(
-                potency=200,
+                potency=160,
                 damage_class=DamageClass.PET,
                 pet_job_mod_override=100,
                 pet_scalar=0.88,
@@ -639,7 +677,7 @@ def add_smn_skills(skill_library):
         name="Luxwave",
         is_GCD=False,
         damage_spec=DamageSpec(
-            potency=200,
+            potency=160,
             damage_class=DamageClass.PET,
             pet_job_mod_override=100,
             pet_scalar=0.88,
@@ -705,6 +743,7 @@ def add_smn_skills(skill_library):
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=670,
             ),
+            has_aoe=True
         )
     )
 
@@ -712,12 +751,43 @@ def add_smn_skills(skill_library):
         Skill(
             name="Sunflare",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=700),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=700)},
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=base_animation_lock + smn_caster_tax_ms,
                 application_delay=670,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.6
+        )
+    )
+
+    exodus_follow_up = FollowUp(
+        skill=Skill(
+            name="Exodus (Pet)",
+            is_GCD=False,
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(
+                potency=1600,
+                damage_class=DamageClass.PET,
+                pet_job_mod_override=100,
+                pet_scalar=0.88,
+            )},
+            timing_spec=instant_timing_spec,
+            has_aoe=True,
+            aoe_dropoff=0.6,
+        ),
+        delay_after_parent_application=0,
+        snapshot_buffs_with_parent=False,
+        snapshot_debuffs_with_parent=False,
+        primary_target_only=False
+    )
+
+    skill_library.add_skill(
+        Skill(
+            name="Exodus",
+            is_GCD=False,
+            timing_spec=instant_timing_spec,
+            follow_up_skills=(exodus_follow_up,)
         )
     )
 
@@ -725,28 +795,11 @@ def add_smn_skills(skill_library):
         Skill(
             name="Enkindle Solar Bahamut",
             is_GCD=False,
-            damage_spec=DamageSpec(
-                potency=1600,
-                damage_class=DamageClass.PET,
-                pet_job_mod_override=100,
-                pet_scalar=0.88,
-            ),
-            timing_spec=instant_timing_spec,
-        )
-    )
-    skill_library.add_skill(
-        Skill(
-            name="Exodus",
-            is_GCD=False,
-            damage_spec=DamageSpec(
-                potency=1600,
-                damage_class=DamageClass.PET,
-                pet_job_mod_override=100,
-                pet_scalar=0.88,
-            ),
             timing_spec=instant_timing_spec,
+            follow_up_skills=(exodus_follow_up,)
         )
     )
+
     skill_library.add_skill(
         Skill(
             name="Aethercharge",
