@@ -146,6 +146,7 @@ def add_mch_skills(skill_library):
                 dot_duration=i * 1000,
                 snapshot_buffs_with_parent=True,
                 snapshot_debuffs_with_parent=True,
+                primary_target_only=False
             )
         return follow_ups
 
@@ -251,10 +252,12 @@ def add_mch_skills(skill_library):
         Skill(
             name="Ricochet",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=130),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=130)},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5
         )
     )
     skill_library.add_skill(
@@ -279,6 +282,7 @@ def add_mch_skills(skill_library):
                 base_cast_time=0, gcd_base_recast_time=1500, application_delay=890
             ),
             job_resource_spec=(job_resource_spec_gcd,),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -381,7 +385,7 @@ def add_mch_skills(skill_library):
                     guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                     guaranteed_dh=ForcedCritOrDH.FORCE_YES,
                 ),
-                "No Combo": DamageSpec(potency=120),
+                "No Combo": DamageSpec(potency=140),
                 "No Combo, Reassemble": DamageSpec(
                     potency=140,
                     guaranteed_crit=ForcedCritOrDH.FORCE_YES,
@@ -449,11 +453,13 @@ def add_mch_skills(skill_library):
         dot_duration=15 * 1000,
         snapshot_buffs_with_parent=True,
         snapshot_debuffs_with_parent=True,
+        primary_target_only=False
     )
     skill_library.add_skill(
         Skill(
             name="Bioblaster",
             is_GCD=True,
+            has_aoe=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(potency=50),
                 "Reassemble": DamageSpec(
@@ -578,6 +584,7 @@ def add_mch_skills(skill_library):
         Skill(
             name="Scattergun",
             is_GCD=True,
+            has_aoe=True,
             damage_spec={
                 SimConsts.DEFAULT_CONDITION: DamageSpec(potency=160),
                 "Reassemble": DamageSpec(
@@ -611,6 +618,8 @@ def add_mch_skills(skill_library):
                 JobResourceSpec(name="Battery", change=+20),
                 job_resource_spec_gcd,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.65
         )
     )
     skill_library.add_skill(
@@ -676,21 +685,25 @@ def add_mch_skills(skill_library):
         Skill(
             name="Checkmate",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=160),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=160)},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=800
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5
         )
     )
 
     skill_library.add_skill(
         Skill(
             name="Double Check",
-            is_GCD=False,
-            damage_spec=DamageSpec(potency=160),
+            is_GCD=False,            
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=160)},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=800
             ),
+            has_aoe=True,
+            aoe_dropoff=0.5
         )
     )
 
@@ -713,6 +726,8 @@ def add_mch_skills(skill_library):
                 JobResourceSpec(name="Battery", change=+20),
                 job_resource_spec_gcd,
             ),
+            has_aoe=True,
+            aoe_dropoff=0.65
         )
     )
 
@@ -720,15 +735,17 @@ def add_mch_skills(skill_library):
         Skill(
             name="Full Metal Field",
             is_GCD=True,
-            damage_spec=DamageSpec(
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(
                 potency=700,
                 guaranteed_crit=ForcedCritOrDH.FORCE_YES,
                 guaranteed_dh=ForcedCritOrDH.FORCE_YES,
-            ),
+            )},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=1030
             ),
             job_resource_spec=(job_resource_spec_gcd,),
+            has_aoe=True,
+            aoe_dropoff=0.5
         )
     )
 
