@@ -40,7 +40,7 @@ def add_drk_skills(skill_library):
             name="Hard Slash",
             is_GCD=True,
             combo_spec=(ComboSpec(),),
-            damage_spec=DamageSpec(potency=240),
+            damage_spec=DamageSpec(potency=260),
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=581
             ),
@@ -52,8 +52,8 @@ def add_drk_skills(skill_library):
             is_GCD=True,
             combo_spec=(ComboSpec(combo_actions=("Hard Slash",)),),
             damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=340),
-                "No Combo": DamageSpec(potency=200),
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=360),
+                "No Combo": DamageSpec(potency=220),
             },
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=624
@@ -69,6 +69,7 @@ def add_drk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=712
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -87,8 +88,8 @@ def add_drk_skills(skill_library):
             is_GCD=True,
             combo_spec=(ComboSpec(combo_actions=("Syphon Strike",)),),
             damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=420),
-                "No Combo": DamageSpec(potency=200),
+                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=460),
+                "No Combo": DamageSpec(potency=240),
             },
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=624
@@ -99,6 +100,7 @@ def add_drk_skills(skill_library):
     flood_of_shadow_damage_follow_up = FollowUp(
         skill=Skill(name="Flood of Shadow", damage_spec=DamageSpec(potency=160)),
         delay_after_parent_application=624,
+        primary_target_only=False
     )
     skill_library.add_skill(
         Skill(
@@ -109,8 +111,13 @@ def add_drk_skills(skill_library):
             ),
             follow_up_skills=(
                 flood_of_shadow_damage_follow_up,
-                FollowUp(skill=_darkside_buff, delay_after_parent_application=0),
+                FollowUp(
+                    skill=_darkside_buff,
+                    delay_after_parent_application=0,
+                    primary_target_only=True,
+                ),
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -126,6 +133,7 @@ def add_drk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=712
             ),
+            has_aoe=True,
         )
     )
 
@@ -174,16 +182,19 @@ def add_drk_skills(skill_library):
                     snapshot_debuffs_with_parent=False,
                 ),
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
         Skill(
             name="Salt and Darkness",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=500),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=500)},                         
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=757
             ),
+            has_aoe=True,
+            aoe_dropoff= 0.5
         )
     )
     skill_library.add_skill(
@@ -194,6 +205,7 @@ def add_drk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=978
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -224,46 +236,52 @@ def add_drk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=757
             ),
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
         Skill(
             name="Shadowbringer",
             is_GCD=False,
-            damage_spec=DamageSpec(potency=600),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=600)},
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=666
             ),
+            has_aoe=True,
+            aoe_dropoff= 0.5
         )
     )
-    ls_names_and_potency = [('Abyssal Drain (pet)',420),
-                            ('Plunge (pet)',420),
-                            ('Shadowbringer (pet)', 570),
-                            ('Edge of Shadow (pet)',420),
-                            ('Bloodspiller (pet)',420),                            
-                            ('Disesteem (pet)',620)]
-    
-    _living_shadow_follow_up_skills = []
-    for skill_name, potency in ls_names_and_potency:
-        sk = Skill(
-            name=skill_name,
-            is_GCD=False,
-            damage_spec=DamageSpec(
-                potency=potency, damage_class=DamageClass.PET, pet_job_mod_override=100
+    ls_names_and_potency_and_delays = [
+        ("Abyssal Drain (pet)", 420, 6800),
+        # blank for where plunge was
+        ("Shadowbringer (pet)", 570, 6800 + 2*2200),
+        ("Edge of Shadow (pet)", 420, 6800 + 3*2200),
+        ("Bloodspiller (pet)", 420, 6800 + 4*2200),
+        ("Disesteem (pet)", 620, 6800 + 5*2200),
+    ]
+
+    _living_shadow_follow_ups = []
+    for skill_name, potency, delay in ls_names_and_potency_and_delays:
+        fu = FollowUp(
+            skill=Skill(
+                name=skill_name,
+                is_GCD=False,
+                damage_spec=DamageSpec(
+                    potency=potency,
+                    damage_class=DamageClass.PET,
+                    pet_job_mod_override=100,
+                ),
+                status_effect_denylist=("Darkside",),
             ),
-            status_effect_denylist=("Darkside",),        
-        )
-        _living_shadow_follow_up_skills.append(sk)
- 
-    _living_shadow_follow_ups = tuple(
-        FollowUp(
-            skill=_living_shadow_follow_up_skills[i],
-            delay_after_parent_application=6800 + i * 2200,
+            delay_after_parent_application=delay,
             snapshot_buffs_with_parent=False,
             snapshot_debuffs_with_parent=False,
         )
-        for i in range(0, len(_living_shadow_follow_up_skills))
-    )
+        _living_shadow_follow_ups.append(fu)           
+
+    _living_shadow_follow_ups = tuple(_living_shadow_follow_ups)
+
+    # TODO: be able to have certain parts of this skill cleave
     skill_library.add_skill(
         Skill(
             name="Living Shadow",
@@ -312,16 +330,19 @@ def add_drk_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=581
             ),
+            has_aoe=True
         )
     )
     skill_library.add_skill(
         Skill(
             name="Disesteem",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=800),
+            damage_spec={SimConsts.DEFAULT_CONDITION: DamageSpec(potency=800)},                         
             timing_spec=TimingSpec(
                 base_cast_time=0, animation_lock=650, application_delay=581
             ),
+            has_aoe=True,
+            aoe_dropoff= 0.5
         )
     )
     # These skills do not damage, but grants resources/affects future skills.
