@@ -1,7 +1,7 @@
 import pandas as pd #i need to get rid of this...
 
 from collections import namedtuple
-from simulator.skills.skill_modifier import SkillModifier
+from ama_xiv_combat_sim.simulator.skills.skill_modifier import SkillModifier
 
 #@title CSVUtils
 class RotationCSV(namedtuple('RotationCSV', ['t', 'skill_name', 'job_class', 'skill_conditional'])):
@@ -25,7 +25,8 @@ class CSVUtils():
       skill_conditional = df['skill_conditional'][i]
       res.append(RotationCSV(t, skill_name, job_class, skill_conditional))
     return res
-
+  
+  @staticmethod
   def populate_rotation_from_csv(rb, filename):
     all_skills = CSVUtils.read_rotation_from_csv(filename)
     for sk in all_skills:
